@@ -33,7 +33,7 @@ def get_pretrained_network(file_id=None,
 
     def switch_networks(argument):
         switcher = {
-            "arterialLesionWeibinShi": "https://figshare.com/ndownloader/files/30761716",
+            "arterialLesionWeibinShi": "https://figshare.com/ndownloader/files/31624922",
             "brainAgeGender": "https://ndownloader.figshare.com/files/22179948",
             "brainAgeDeepBrainNet": "https://ndownloader.figshare.com/files/23573402",
             "brainExtraction": "https://ndownloader.figshare.com/files/22944632",
@@ -65,6 +65,10 @@ def get_pretrained_network(file_id=None,
             "deepFlashRightT1Hierarchical": "https://figshare.com/ndownloader/files/31226452",
             "deepFlashLeftBothHierarchical": "https://figshare.com/ndownloader/files/31226458",
             "deepFlashRightBothHierarchical": "https://figshare.com/ndownloader/files/31226455",
+            "deepFlashLeftT1Hierarchical_ri": "https://figshare.com/ndownloader/files/33198794",
+            "deepFlashRightT1Hierarchical_ri": "https://figshare.com/ndownloader/files/33198800",
+            "deepFlashLeftBothHierarchical_ri": "https://figshare.com/ndownloader/files/33198803",
+            "deepFlashRightBothHierarchical_ri": "https://figshare.com/ndownloader/files/33198809",
             "deepFlash": "https://ndownloader.figshare.com/files/22933757",
             "deepFlashLeft8": "https://ndownloader.figshare.com/files/25441007",
             "deepFlashRight8": "https://ndownloader.figshare.com/files/25441004",
@@ -160,6 +164,10 @@ def get_pretrained_network(file_id=None,
                   "deepFlashRightT1Hierarchical",
                   "deepFlashLeftBothHierarchical",
                   "deepFlashRightBothHierarchical",
+                  "deepFlashLeftT1Hierarchical_ri",
+                  "deepFlashRightT1Hierarchical_ri",
+                  "deepFlashLeftBothHierarchical_ri",
+                  "deepFlashRightBothHierarchical_ri",
                   "deepFlashLeft8",
                   "deepFlashRight8",
                   "deepFlashLeft16",
